.. Prysk documentation master file, created by
   sphinx-quickstart on Fri Jan 28 20:26:40 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Prysk's documentation!
=================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   format
   examples
   development
   news

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
